@@ -6,10 +6,7 @@ import six
 
 from dbnd._core.current import current_task_run
 from dbnd._core.errors import DatabandError
-from dbnd._core.utils.basics.load_python_module import (
-    load_python_callable,
-    run_user_func,
-)
+from dbnd._core.utils.basics.load_python_module import load_python_callable
 from dbnd._core.utils.basics.text_banner import TextBanner
 from dbnd._core.utils.http.constants import AUTHS_SUPPORTED, NO_AUTH
 from dbnd._core.utils.http.endpoint import Endpoint
@@ -79,23 +76,29 @@ class _LivySparkCtrl(SparkCtrl):
         livy_endpoint = self.get_livy_endpoint()
         self.task_run.set_external_resource_urls({"Livy url": livy_endpoint.url})
         logger.info("Connecting to: %s", livy_endpoint)
+        livy_config = self.task_run.task.spark_engine
         livy = LivyBatchClient.from_endpoint(
-            livy_endpoint, ignore_ssl_errors=self.get_livy_ignore_ssl_errors()
+            livy_endpoint,
+            status_code_retries=livy_config.retry_on_status_error,
+            ignore_ssl_errors=self.get_livy_ignore_ssl_errors(),
         )
         batch = livy.post_batch(data)
-        self._run_post_submit_hook(batch)
+        self._run_hook(batch, self.livy_config.job_submitted_hook)
         livy.track_batch_progress(
             batch["id"], status_reporter=self._report_livy_batch_status
         )
 
-    def _run_post_submit_hook(self, batch_response):
+    @property
+    def livy_config(self) -> LivySparkConfig:
+        return self.task_run.task.spark_engine
+
+    def _run_hook(self, batch_response: Dict[str, Any], hook_function_path: str):
         """running a callable after submitting the batch to Livy"""
 
-        livy_config = self.task_run.task.spark_engine  # type: LivySparkConfig
-        user_callable_path = livy_config.post_submit_hook
+        user_callable_path = hook_function_path
         if user_callable_path is not None:
             logger.debug(
-                "Executing Livy post submit hook callable at {callable}".format(
+                "Executing Livy hook; callable at {callable}".format(
                     callable=user_callable_path
                 )
             )
@@ -122,12 +125,13 @@ class _LivySparkCtrl(SparkCtrl):
                     raise
 
                 logger.debug(
-                    "Successfully executed Livy post submit hook callable at `{callable}`".format(
+                    "Successfully executed Livy hook;  callable at `{callable}`".format(
                         callable=user_callable_path
                     )
                 )
 
     def _report_livy_batch_status(self, batch_response):
+        self._run_hook(batch_response, self.livy_config.job_status_hook)
         logger.info(self._get_batch_progresss_banner(batch_response))
 
     def _get_batch_progresss_banner(self, batch_response):
